@@ -1,10 +1,29 @@
 import logging
+from enum import Enum
+from functools import lru_cache
 from types import FrameType
 from typing import cast
 
 from loguru import logger
 
-__all__ = ["InterceptHandler"]
+__all__ = ["get_intercept_handler", "LoggingLevel"]
+
+
+import logging
+from enum import Enum
+
+
+class LoggingLevel(str, Enum):
+    CRITICAL = "critical"
+    ERROR = "error"
+    WARNING = "warning"
+    INFO = "info"
+    DEBUG = "debug"
+    NOTSET = "notset"
+
+    @property
+    def level(self) -> int:
+        return logging.getLevelName(self.name)
 
 
 class InterceptHandler(logging.Handler):
@@ -25,3 +44,8 @@ class InterceptHandler(logging.Handler):
             level,
             record.getMessage(),
         )
+
+
+@lru_cache
+def get_intercept_handler(logging_level: int) -> InterceptHandler:
+    return InterceptHandler(logging_level)
